@@ -5,11 +5,12 @@ package Eoldutf8;
 #
 #                  http://search.cpan.org/dist/OldUTF8/
 #
-# Copyright (c) 2008, 2009, 2010 INABA Hitoshi <ina@cpan.org>
+# Copyright (c) 2008, 2009, 2010, 2011 INABA Hitoshi <ina@cpan.org>
 #
 ######################################################################
 
 use 5.00503;
+use strict qw(subs vars);
 
 # 12.3. Delaying use Until Runtime
 # in Chapter 12. Packages, Libraries, and Modules
@@ -17,17 +18,30 @@ use 5.00503;
 # (and so on)
 
 BEGIN { eval q{ use vars qw($VERSION) } }
-$VERSION = sprintf '%d.%02d', q$Revision: 0.69 $ =~ m/(\d+)/xmsg;
-
-# use strict qw(subs vars);
-BEGIN {
-    eval { require strict; 'strict'->import(qw(subs vars)); };
-}
+$VERSION = sprintf '%d.%02d', q$Revision: 0.70 $ =~ m/(\d+)/xmsg;
 
 BEGIN {
     my $PERL5LIB = __FILE__;
+
+    # DOS-like system
+    if ($^O =~ /\A (?: MSWin32 | NetWare | symbian | dos ) \z/oxms) {
         $PERL5LIB =~ s{[^/]*$}{OldUTF8};
-    unshift @INC, $PERL5LIB;
+    }
+
+    # UNIX-like system
+    else {
+        $PERL5LIB =~ s{[^/]*$}{OldUTF8};
+    }
+
+    my @inc = ();
+    my %inc = ();
+    for my $path ($PERL5LIB, @INC) {
+        if (not exists $inc{$path}) {
+            push @inc, $path;
+            $inc{$path} = 1;
+        }
+    }
+    @INC = @inc;
 }
 
 BEGIN {
@@ -105,6 +119,7 @@ BEGIN {
     }
 
     sub qualify_to_ref ($;$) {
+        no strict qw(refs);
         return \*{ qualify $_[0], @_ > 1 ? $_[1] : caller };
     }
 }
@@ -130,10 +145,6 @@ sub confess(@);
 
 my $__FILE__ = __FILE__;
 
-BEGIN { eval q{ use vars qw($_warning) } }
-$_warning = $^W; # push warning, warning on
-local $^W = 1;
-
 BEGIN {
     if ($^X =~ m/ jperl /oxmsi) {
         die "$0 need perl(not jperl) 5.00503 or later. (\$^X==$^X)";
@@ -283,7 +294,14 @@ sub Eoldutf8::split(;$$$) {
     my $limit   = $_[2];
 
     # if $string is omitted, the function splits the $_ string
-    $string = $_ if not defined $string;
+    if (not defined $string) {
+        if (defined $_) {
+            $string = $_;
+        }
+        else {
+            $string = '';
+        }
+    }
 
     my @split = ();
 
@@ -297,7 +315,7 @@ sub Eoldutf8::split(;$$$) {
 
         # count of substrings in scalar context
         else {
-            cluck "$0: Use of implicit split to \@_ is deprecated" if $^W;
+            carp "$0: Use of implicit split to \@_ is deprecated" if $^W;
             @_ = @split;
             return scalar @_;
         }
@@ -407,7 +425,7 @@ sub Eoldutf8::split(;$$$) {
 
     # count of substrings in scalar context
     else {
-        cluck "$0: Use of implicit split to \@_ is deprecated" if $^W;
+        carp "$0: Use of implicit split to \@_ is deprecated" if $^W;
         @_ = @split;
         return scalar @_;
     }
@@ -566,37 +584,9 @@ sub Eoldutf8::rindex($$;$) {
 # old UTF-8 regexp capture
 #
 {
-    # 10.3. Creating Persistent Private Variables
-    # in Chapter 10. Subroutines
-    # of ISBN 0-596-00313-7 Perl Cookbook, 2nd Edition.
-
-    my $last_s_matched = 0;
-
     sub Eoldutf8::capture($) {
-        if ($last_s_matched and ($_[0] =~ m/\A [1-9][0-9]* \z/oxms)) {
-            return $_[0] + 1;
-        }
         return $_[0];
     }
-
-    # old UTF-8 regexp mark last m// or qr// matched
-    sub Eoldutf8::m_matched() {
-        $last_s_matched = 0;
-    }
-
-    # old UTF-8 regexp mark last s/// or qr matched
-    sub Eoldutf8::s_matched() {
-        $last_s_matched = 1;
-    }
-
-    # which matched of m// or s/// at last
-
-    # P.854 31.17. use re
-    # in Chapter 31. Pragmatic Modules
-    # of ISBN 0-596-00027-8 Programming Perl Third Edition.
-
-    @Eoldutf8::m_matched = (qr/(?{Eoldutf8::m_matched})/);
-    @Eoldutf8::s_matched = (qr/(?{Eoldutf8::s_matched})/);
 }
 
 #
@@ -1319,13 +1309,13 @@ sub _dosglob {
     #
     # and File::HomeDir, File::HomeDir::Windows module
 
-    # DOS like system
+    # DOS-like system
     if ($^O =~ /\A (?: MSWin32 | NetWare | symbian | dos ) \z/oxms) {
         $expr =~ s{ \A ~ (?= [^/\\] ) }
                   { $ENV{'HOME'} || $ENV{'USERPROFILE'} || "$ENV{'HOMEDRIVE'}$ENV{'HOMEPATH'}" }oxmse;
     }
 
-    # UNIX like system
+    # UNIX-like system
     else {
         $expr =~ s{ \A ~ ( (?:(?:[\xC0-\xDF]|[\xE0-\xEF][\x80-\xBF]|[\xF0-\xF4][\x80-\xBF][\x80-\xBF])[\x00-\xFF]|[^/])* ) }
                   { $1 ? (getpwnam($1))[7] : ($ENV{'HOME'} || $ENV{'LOGDIR'} || (getpwuid($<))[7]) }oxmse;
@@ -1550,6 +1540,7 @@ sub _parse_path {
 #
 sub Eoldutf8::binmode(*;$) {
     if (@_ == 1) {
+        local $^W = 0;
         if (ref $_[0]) {
             my $filehandle = qualify_to_ref $_[0];
             return CORE::binmode $filehandle;
@@ -1562,6 +1553,7 @@ sub Eoldutf8::binmode(*;$) {
         my(undef,$layer) = @_;
         $layer =~ s/ :? encoding\($encoding_alias\) //oxms;
         if ($layer =~ m/\A :raw \z/oxms) {
+            local $^W = 0;
             if ($_[0] =~ m/\A (?: STDIN | STDOUT | STDERR ) \z/oxms) {
                 return CORE::binmode $_[0];
             }
@@ -1595,6 +1587,7 @@ sub Eoldutf8::open(*;$@) {
     }
     elsif (@_ == 1) {
         my $filehandle = gensym;
+        local $^W = 0;
         my $expr = ${(caller(1))[0] . "::$_[0]"};
         my $ref = \${(caller(1))[0] . "::$_[0]"};
         *{(caller(1))[0] . "::$_[0]"} = $filehandle;
@@ -1880,9 +1873,6 @@ sub confess(@) {
     croak @_;
 }
 
-# pop warning
-$^W = $_warning;
-
 1;
 
 __END__
